@@ -89,14 +89,3 @@ class BtcBaseConnectionProtocol(AbstractBlockchainConnectionProtocol):
     @abstractmethod
     def _build_get_blocks_message_for_block_confirmation(self, hashes: List[Sha256Hash]) -> AbstractMessage:
         pass
-
-    @abstractmethod
-    def _set_transaction_contents(self, tx_hash: Sha256Hash, tx_content: Union[memoryview, bytearray]) -> None:
-        """
-        set the transaction contents in the connection transaction service.
-        since some buffers needs to be copied while others should not, this handler was added.
-        avoid calling transaction_service.set_transactions_contents directly from this class or its siblings.
-        :param tx_hash: the transaction hash
-        :param tx_content: the transaction contents buffer
-        """
-        pass
