@@ -94,9 +94,6 @@ RELAY_CONNECTION_REEVALUATION_INTERVAL_S = 4 * 60 * 60
 
 BLOCK_QUEUE_LENGTH_LIMIT = 128
 
-QUOTA_NOTIFICATION_IGNORE_REPEAT_WINDOW_S = 60
-
-
 LOCALHOST = "127.0.0.1"
 
 TRACKED_BLOCK_MAX_HASH_LOOKUP = 100
@@ -106,9 +103,11 @@ BLOCKCHAIN_TX_PROCESSING_TIME_WARNING_THRESHOLD_S = 0.05
 
 WS_DEFAULT_PORT = 28333
 WS_DEFAULT_HOST = LOCALHOST
-RPC_SUBSCRIBER_MAX_QUEUE_SIZE = 500
+RPC_SUBSCRIBER_MAX_QUEUE_SIZE = 1000
 WS_MIN_RECONNECT_TIMEOUT_S = 1
 WS_RECONNECT_TIMEOUTS = [1, 2, 3, 5, 8, 13]
+WS_MAX_CONNECTION_TIMEOUT_S = 2
 
-PENDING_TX_FEED_CONSIDER_INACTIVE_INTERVAL_S = 60
 WS_PROVIDER_MAX_QUEUE_SIZE = 1000
+
+ADDITIONAL_BLOCKCHAIN_RECONNECT_TIMEOUT_S = 3
