@@ -41,7 +41,7 @@ def get_gateway_opts(
     block_interval=600,
     non_ssl_port: int = 9001,
     has_fully_updated_tx_service: bool = False,
-    max_block_interval: int = 10,
+    max_block_interval: float = 10,
     default_tx_quota_type: QuotaType = QuotaType.FREE_DAILY_QUOTA,
     log_level_overrides=None,
     enable_network_content_logs=False,
@@ -58,9 +58,9 @@ def get_gateway_opts(
     if node_id is None:
         node_id = "Gateway at {0}".format(port)
     if peer_gateways is None:
-        peer_gateways = []
+        peer_gateways = set()
     if peer_relays is None:
-        peer_relays = []
+        peer_relays = set()
     if peer_transaction_relays is None:
         peer_transaction_relays = []
     if blockchain_address is None:
@@ -78,7 +78,7 @@ def get_gateway_opts(
     for kwarg, arg in partial_apply_args["kwargs"].items():
         partial_apply_args[kwarg] = arg
 
-    partial_apply_args["outbound_peers"] = peer_gateways + peer_relays
+    partial_apply_args["outbound_peers"] = set(peer_gateways).union(peer_relays)
 
     opts = Namespace()
     common_opts = get_common_opts(**partial_apply_args)
@@ -130,7 +130,6 @@ def get_gateway_opts(
             "ws_host": constants.LOCALHOST,
             "ws_port": 28333,
             "account_id": account_id,
-            "account_model": account_model,
             "ipc": False,
             "ipc_file": "bxgateway.ipc",
             "request_remote_transaction_streaming": request_remote_transaction_streaming,
@@ -181,9 +180,9 @@ def get_gateway_opts(
     for key, val in kwargs.items():
         opts.__dict__[key] = val
 
-    # validation messes up tests
-    GatewayOpts.validate_blockchain_ip = MagicMock()
-    gateway_opts = GatewayOpts(opts)
+    gateway_opts = GatewayOpts.from_opts(opts)
+    if account_model:
+        gateway_opts.set_account_options(account_model)
 
     # some attributes are usually set by the node runner
     gateway_opts.__dict__.update({
